% Detailed explanation goes here:
% solve the problem: [solution_str,outargstruc_arr]=tbpsg_run(problem_statement,toolboxstruc_arr)
% get the optimal point data: output = tbpsg_optimal_point_data(solution_str, outargstruc_arr)
% get the optimal point vars: output = tbpsg_optimal_point_vars(solution_str, outargstruc_arr)
% original data are sorted by the banks: BBT, STT, PNC, COF, USB, BK, WFC,
% C,JPM,BAC

clc
clear

load data_CVaR2_err.mat original_matrix original_benchmark var_01 var_05

vars={'intercept','vix','ls','tc','tsc','csc','er','reer','stockreturn'}; %define the variables, including intercept
alpha=0.9;

for i=1:10 % n denotes the number of bank
    % Prepare data for subroutine
    matrix=original_matrix(:,(9*(i-1)+1):(9*(i-1)+9)); %Bank i's data_matrix
    benchmark=original_benchmark; % Bank i's benchmark vector   
    
    % Run subroutine to minimize KB error
    disp(sprintf('Problem # %g',i))
    [solution_str,outargstruc_arr] = minimize_CVaR2_err(matrix,vars,benchmark,alpha);
    disp(' ')
    
    % Extract from the solution report optimal point data and vars
    solution_result(i,:)=tbpsg_optimal_point_data(solution_str, outargstruc_arr); % store the optimal variables of different banks
    solution_varialbe(i,:)=tbpsg_optimal_point_vars(solution_str, outargstruc_arr);%store the variables name of the solution
    
    % Extract from the solution report pseudo R square
    names = tbpsg_function_names(solution_str, outargstruc_arr);
    val = tbpsg_function_data(solution_str, outargstruc_arr); % get the objective value, Pseduo R square and adjusted Pseduo R square
    Pseduo_R_square(i)=val(find(strcmp(names,'adjusted_pseudo_r2_cvar2_err(0.9,matrix_cvar_reg)')));
    
    clear val matrix benchmark solution_str outargstruc_arr names
    
end

% Sort optimal point data to the initial orderpos = [];
pos=[];
for i=1:size(vars,2)
   pos = [pos, find(strcmp(solution_varialbe(1,:),vars{i}))];
end
output_result = solution_result(:,pos);    

% Uncomment to export results
%xlswrite('H:\cocvar data\cocvar_regression_coefficient',output_result);

for i=1:length(original_matrix(:,1))
    for j=1:10
    sub_original_matrix=original_matrix(:,(9*(j-1)+1):(9*(j-1)+9));
    cocvar_bank_01(i,j)=sub_original_matrix(i,7)*-1*output_result(j,1)+sub_original_matrix(i,3)*-1*output_result(j,2)+sub_original_matrix(i,4)*-1*output_result(j,3)+sub_original_matrix(i,6)*-1*output_result(j,4)+sub_original_matrix(i,5)*-1*output_result(j,5)+sub_original_matrix(i,2)*-1*output_result(j,6)+sub_original_matrix(i,8)*-1*output_result(j,7)+sub_original_matrix(i,1)*-1*output_result(j,8)+var_01(i,j)*-1*output_result(j,9);
    clear sub_original_matrix
    end
end
for i=1:length(original_matrix(:,1))
    for j=1:10
    sub_original_matrix=original_matrix(:,(9*(j-1)+1):(9*(j-1)+9));
    cocvar_bank_05(i,j)=sub_original_matrix(i,7)*-1*output_result(j,1)+sub_original_matrix(i,3)*-1*output_result(j,2)+sub_original_matrix(i,4)*-1*output_result(j,3)+sub_original_matrix(i,6)*-1*output_result(j,4)+sub_original_matrix(i,5)*-1*output_result(j,5)+sub_original_matrix(i,2)*-1*output_result(j,6)+sub_original_matrix(i,8)*-1*output_result(j,7)+sub_original_matrix(i,1)*-1*output_result(j,8)+var_05(i,j)*-1*output_result(j,9);
    clear sub_original_matrix
    end
end
delta_cocvar=cocvar_bank_01-cocvar_bank_05;
mean_delta_cocvar=mean(delta_cocvar);

% Uncomment to export results
%xlswrite('.\cocvar data\delta_cocvar',delta_cocvar);

% Plot figure
subplot(5,2,1);
plot(delta_cocvar(:,1));
subplot(5,2,2);
plot(delta_cocvar(:,2));
subplot(5,2,3);
plot(delta_cocvar(:,3));
subplot(5,2,4);
plot(delta_cocvar(:,4));
subplot(5,2,5);
plot(delta_cocvar(:,5));
subplot(5,2,6);
plot(delta_cocvar(:,6));
subplot(5,2,7);
plot(delta_cocvar(:,7));
subplot(5,2,8);
plot(delta_cocvar(:,8));
subplot(5,2,9);
plot(delta_cocvar(:,9));
subplot(5,2,10);
plot(delta_cocvar(:,10));





